@@ -10,7 +10,7 @@ __license__ = "GPL"
 __version__ = "$Revision: 12897 $"
 
 from zope.interface import Interface
-from zope.schema import Float
+from zope.schema import Float,TextLine
 
 class IMTime(Interface):
 
@@ -18,3 +18,8 @@ class IMTime(Interface):
         title=u"Modification time",
         description=u"Last modification time in second from Unix Epoch"
         )
+
+    def strftime(format=TextLine(title=u"TimeDate Format")) :
+        """ Return datetime as string using format argument """
+        return time.strftime("%Y-%m-%d %H:%M:%S",time.localtime(0))
+        
\ No newline at end of file
